// java wrapper for vtkXMLFileReadTester object
//

package vtk;
import vtk.*;

public class vtkXMLFileReadTester extends vtkXMLParser
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int TestReadFile_2();
  public int TestReadFile()
    { return TestReadFile_2(); }

  private native String GetFileDataType_3();
  public String GetFileDataType()
    { return GetFileDataType_3(); }

  private native String GetFileVersion_4();
  public String GetFileVersion()
    { return GetFileVersion_4(); }

  public vtkXMLFileReadTester() { super(); }

  public vtkXMLFileReadTester(long id) { super(id); }
  public native long   VTKInit();

}
